@@ -4,9 +4,12 @@
 #
 from ebbe.functions import (
     as_chunks,
+    fail_fast,
     uniq,
     with_prev,
+    with_prev_and_next,
     with_next,
     with_is_first,
-    with_is_last
+    with_is_last,
+    without_first
 )
