@@ -4,6 +4,10 @@
 #
 
 
+def empty_generator():
+    yield from ()
+
+
 def as_chunks(size, iterable):
     chunk = []
 
@@ -18,6 +22,21 @@ def as_chunks(size, iterable):
         yield chunk
 
 
+def fail_fast(iterable):
+    iterator = iter(iterable)
+
+    try:
+        first_item = next(iterator)
+    except StopIteration:
+        return empty_generator()
+
+    def generator():
+        yield first_item
+        yield from iterator
+
+    return generator()
+
+
 def uniq(iterable):
     current_item = None
 
@@ -57,6 +76,23 @@ def with_next(iterable):
     yield last, None
 
 
+def with_prev_and_next(iterable):
+    prev = None
+    iterator = iter(iterable)
+
+    try:
+        last = next(iterator)
+    except StopIteration:
+        return
+
+    for item in iterator:
+        yield prev, last, item
+        prev = last
+        last = item
+
+    yield prev, last, None
+
+
 def with_is_first(iterable):
     is_first = True
 
@@ -78,3 +114,11 @@ def with_is_last(iterable):
         last = item
 
     yield True, last
+
+
+def without_first(iterable):
+    for is_first, item in with_is_first(iterable):
+        if is_first:
+            continue
+
+        yield item
